typedef struct vlc_jobqueue_t vlc_jobqueue_t;
typedef struct vlc_job_t vlc_job_t;

/*
 *
 * job API
 *
 */
VLC_API vlc_job_t *
vlc_job_New(const char *url, const char *name);

VLC_API vlc_job_t *
vlc_job_Hold(vlc_job_t *);

VLC_API void
vlc_job_Release(vlc_job_t *);

VLC_API bool
vlc_job_IsActive(const vlc_job_t *);

VLC_API const char *
vlc_job_GetItemUrl(const vlc_job_t *);

VLC_API const char *
vlc_job_GetItemName(const vlc_job_t *);

/*
 *
 * jobqueue API
 *
 */

/* vlc_server_t module name: httpd, upnp, vlm, transcode */
VLC_API const char *
vlc_jobqueue_GetServerName(vlc_jobqueue_t *jobqueue);

/* Like "http server on address:port" */
VLC_API const char *
vlc_jobqueue_GetServerDisplayName(vlc_jobqueue_t *jobqueue);

VLC_API bool
vlc_jobqueue_CanMoveJobs(vlc_jobqueue_t *jobqueue);

/* vlc_jobqueue_GetJobAt(), vlc_jobqueue_GetJobCount(), vlc_jobqueue_MoveJob(),
 * need to be locked */
VLC_API void
vlc_jobqueue_Lock(vlc_jobqueue_t *jobqueue);

VLC_API void
vlc_jobqueue_Unlock(vlc_jobqueue_t *jobqueue);

VLC_API const vlc_job_t *
vlc_jobqueue_GetJobAt(vlc_jobqueue_t *jobqueue, size_t index);

VLC_API size_t
vlc_jobqueue_GetJobCount(vlc_jobqueue_t *jobqueue);

VLC_API int
vlc_jobqueue_MoveJob(vlc_jobqueue_t *jobqueue, size_t index, size_t count,
                     size_t target);

/*
 *
 * Getters from any interfaces modules
 *
 */

/* Get the list of all active servers, by name */
VLC_API char **
vlc_intf_GetServerNames(intf_thread_t *intf, size_t *count);

/* Get a job queue from a server name */
VLC_API vlc_jobqueue_t *
vlc_intf_GetJobQueue(intf_thread_t *intf, const char *server_name);
